my %parameter = (path => $settings->{cgi}{bin} . '/templates', style => $style, title => "", server => $settings->{serverName}, id => 'exploit', class => 'min',);
my $window = new HTML::Window(\%parameter);
$window->set_closeable(0);
$window->set_moveable(0);
$window->set_resizeable(1);
print br(),;
print $window->windowHeader();
print translate("Permission denied"), br(), "remote_addr: $remote_addr", br(),"query_string: $query_string",br(),"referer: $referer",br();
my $remote_addr  = CGI::remote_addr()  ? CGI::remote_addr()  : 'none';
my $query_string = CGI::query_string() ? CGI::query_string() : 'none';
my $referer      = CGI::referer()      ? CGI::referer()      : 'none';
$database->void("INSERT INTO exploit(referer,remote_addr,query_string) VALUES (?,?,?)", $referer, $remote_addr, $query_string);
print $@ if $@;
print $window->windowFooter();
